absenteeism: Absenteeism data

absenteeismR Documentation

Absenteeism data

Description

Fictional data on absenteeism in a large technology company

Usage

absenteeism

Format

A dataframe with 865 rows and 4 variables:

days_absent

The number of unscheduled days of absence for the employee in the last calendar year

tenure

The employee’s tenure at the company in years

is_manager

A binary value indicating 1 if the employee is a manager and 0 if not

performance_rating

The employee’s most recent performance score on an increasing scale from 1 to 5

Examples

absenteeism

peopleanalyticsdata documentation built on July 2, 2026, 1:07 a.m.