Learn R Programming

peopleanalyticsdata (version 0.1.0)

health_insurance: Health insurance data

Description

Fictional data on the demographics and the choice of health insurance policy by employees of a large company

Usage

health_insurance

Arguments

Format

A dataframe with 1453 rows and 6 variables:

product

The choice of policy the individual - A, B or C

age

The age of the individual when they made the choice

children

The number of child dependents the individual had at the time of the choice

position_level

Position level in the company at the time they made the choice, where 1 is is the lowest and 5 is the highest

gender

The gender of the individual as stated when they made the choice

tenure

Full years employed by the company at the time they made the choice

Examples

Run this code
# NOT RUN {
health_insurance
# }

Run the code above in your browser using DataLab