selection: Selection data

selectionR Documentation

Selection data

Description

Fictional data on the hiring process of candidates for a graduate hiring program

Usage

selection

Format

A dataframe with 70 rows and 5 variables:

GPA

The undergraduate Grade Point Average (GPA) of the candidate, on a scale from 1.0 to 4.0

Test

The score of the candidate on a written test out of a maximum of 15

Pres

The average rating of the candidate from a presentation to a panel, on a scale from 1 (Low) to 5 (High)

Int

The rating of the candidate from a one-on-one interview, on an integer scale from 1 (Low) to 5 (High)

Hire

A binary variable indicating whether the candidate was hired (1) or not (0)

Examples

selection

peopleanalyticsdata documentation built on July 2, 2026, 1:07 a.m.