powered by
Fictional data on the demographics and the choice of health insurance policy by employees of a large company
health_insurance
A dataframe with 1453 rows and 6 variables:
The choice of policy the individual - A, B or C
The age of the individual when they made the choice
The number of child dependents the individual had at the time of the choice
Position level in the company at the time they made the choice, where 1 is is the lowest and 5 is the highest
The gender of the individual as stated when they made the choice
Full years employed by the company at the time they made the choice
# NOT RUN { health_insurance # }
Run the code above in your browser using DataLab