| selection | R Documentation |
Fictional data on the hiring process of candidates for a graduate hiring program
selection
A dataframe with 70 rows and 5 variables:
The undergraduate Grade Point Average (GPA) of the candidate, on a scale from 1.0 to 4.0
The score of the candidate on a written test out of a maximum of 15
The average rating of the candidate from a presentation to a panel, on a scale from 1 (Low) to 5 (High)
The rating of the candidate from a one-on-one interview, on an integer scale from 1 (Low) to 5 (High)
A binary variable indicating whether the candidate was hired (1) or not (0)
selection
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.